Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1245)

Unified Diff: base/time/time_unittest.cc

Issue 864943002: Replaces instances of the deprecated TimeTicks::HighResNow() with TimeTicks::Now(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: More changes based on review comments. Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/time/time_posix.cc ('k') | base/time/time_win_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/time/time_unittest.cc
diff --git a/base/time/time_unittest.cc b/base/time/time_unittest.cc
index 07b1e6b77e704b25fc5198a8c3d4756245ea51aa..27f71b46a60b6aad84ebb041ec56d9ad7ee4b789 100644
--- a/base/time/time_unittest.cc
+++ b/base/time/time_unittest.cc
@@ -643,8 +643,8 @@ TEST(TimeTicks, Deltas) {
}
static void HighResClockTest(TimeTicks (*GetTicks)()) {
- // HighResNow doesn't work on some systems. Since the product still works
- // even if it doesn't work, it makes this entire test questionable.
+ // IsHighResolution() is false on some systems. Since the product still works
+ // even if it's false, it makes this entire test questionable.
if (!TimeTicks::IsHighResolution())
return;
@@ -679,8 +679,8 @@ static void HighResClockTest(TimeTicks (*GetTicks)()) {
EXPECT_TRUE(success);
}
-TEST(TimeTicks, HighResNow) {
- HighResClockTest(&TimeTicks::HighResNow);
+TEST(TimeTicks, HighRes) {
+ HighResClockTest(&TimeTicks::Now);
}
// Fails frequently on Android http://crbug.com/352633 with:
@@ -711,7 +711,7 @@ TEST(TimeTicks, MAYBE_ThreadNow) {
}
TEST(TimeTicks, NowFromSystemTraceTime) {
// Re-use HighResNow test for now since clock properties are identical.
HighResClockTest(&TimeTicks::NowFromSystemTraceTime);
}
« no previous file with comments | « base/time/time_posix.cc ('k') | base/time/time_win_unittest.cc » ('j') | no next file with comments »
@@ -711,7 +711,7 @@ TEST(TimeTicks, MAYBE_ThreadNow) {
}
TEST(TimeTicks, NowFromSystemTraceTime) {
- // Re-use HighResNow test for now since clock properties are identical.
+ // Re-use HighRes test for now since clock properties are identical.
HighResClockTest(&TimeTicks::NowFromSystemTraceTime);
}

Powered by Google App Engine
This is Rietveld 408576698